"use strict";

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _FileUtility = require("../../util/FileUtility");

var _FileUtility2 = _interopRequireDefault(_FileUtility);

var _Validation = require("../../util/Validation");

var _Validation2 = _interopRequireDefault(_Validation);

var _Utility = require("../../util/Utility");

var _Utility2 = _interopRequireDefault(_Utility);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var fs = require("fs-extra");
var ReactDocGen = require("react-docgen");

var ReactTransformer = function () {
    function ReactTransformer(config) {
        _classCallCheck(this, ReactTransformer);

        if (!config.root) {
            throw new Error("root configuration is undefined ! ");
        }
        if (!config.sourceFolder) {
            throw new Error("sourceFolder undefined under 'react' property in configuration file.");
        }
        if (!config.extensions) {
            throw new Error("extensions undefined under 'react' property in configuration file.");
        }
        config.sourceFolder = config.root + "/" + config.sourceFolder;
        config.destinationFolder = config.root + "/" + (config.destinationFolder ? config.destinationFolder : "");
        this.config = config;
        if (!_FileUtility2.default.isExist(config.destinationFolder)) {
            throw new Error(config.destinationFolder + " folder is not found ! ");
        }
        if (!config.hashFile) {
            config.hashFile = ".hash";
        }

        if (!_Validation2.default.startsWith(config.hashFile, "/")) {
            config.hashFile = config.destinationFolder + "/" + config.hashFile;
        }

        if (!_FileUtility2.default.isExist(config.hashFile)) {
            _FileUtility2.default.createFile(config.hashFile, "{}");
        }
        this.hash = JSON.parse(_FileUtility2.default.readFile(config.hashFile));
    }

    _createClass(ReactTransformer, [{
        key: "getConfig",
        value: function getConfig() {
            return this.config;
        }
    }, {
        key: "transform",
        value: function transform(fileInformation, source) {

            var isOk = fileInformation.filePath.startsWith(this.config.sourceFolder) && !(fileInformation.filePath.indexOf("index.js") != -1);

            if (!isOk) return;

            if (this.config.extensions.indexOf(fileInformation.extension) === -1) {
                return;
            }
            var newHash = _Utility2.default.hash(source);
            if (this.hash[fileInformation.filePath] && this.hash[fileInformation.filePath] === newHash) {
                return;
            }

            var newFilePath = fileInformation.path.replace(this.config.sourceFolder, this.config.destinationFolder);
            var destinationSrc = null;
            try {
                destinationSrc = ReactDocGen.parse(source);
            } catch (e) {
                console.warn(e);
                return;
            };

            fs.mkdirsSync(newFilePath);
            newFilePath = newFilePath + "/" + fileInformation.name + ".json";
            console.log(newFilePath + " created.");
            fs.outputFileSync(newFilePath, JSON.stringify(destinationSrc));
            this.hash[fileInformation.filePath] = newHash;
            fs.outputFileSync(this.config.hashFile, JSON.stringify(this.hash));
        }
    }]);

    return ReactTransformer;
}();

exports.default = ReactTransformer;